cd "F:\EEH _ 0316025\JV2015_EEH_Replication_Files\Regressions\City Living Standards"

******************************
* CITY LIVING STANDARDS 2010 *
******************************

* As a measure of city living standards in 2010, we use the city product indexes for the period 2000-2010.
* We first use the city product index of the 1998 data set.
* The source is: United Nations Habitat. 1998. Global Urban Indicators Database. Nairobi, Kenya: UNHabitat.

clear
import excel "cdi_100_cities.xls", sheet("summary") firstrow
replace city = "Manila" if city == "Mandaluyong"
sort city
save cdi, replace

* We use the information on city population created by "city_level.do" in the subfolder "City Level". 
use jv2015_city, clear
sort city
merge city using cdi
tab _m
tab city if _m == 2
* These are towns with a population below 300,000 throughout the analysis, so that's ok.
drop _m
keep if product != .
* "product" is the city product index for the year 1998. We will merge this data set with the city product index for the year 2012. 
count
* 115
sum product
gen product2000=product/97.2
* The city product index for the years 1998 and 2012 do not have the same scales.
* We will use the maximal value of the index (97.2) to standardize the two scales, in order to have one scale only.
sum product2000
keep city product2000 p2010
sort city
save corr2000, replace

* We now use the city product index of the 2012 data set.
* The source is: United Nations Habitat. 2012. State of the Worlds Cities Report 2012/2013: Prosperity of Cities. Nairobi, Kenya: UN-Habitat

clear
import excel "cpi_cities.xls", sheet("Feuil1") firstrow clear
sort city
save cpi, replace

use jv2015_city, clear
sort city
merge city using cpi
tab _m
drop _m
* 69 merge
keep if product != .
count
* 69
sum product
* We will use the maximal value of the index (0.94) to standardize the two scales, in order to have one scale only.
gen product2010 = product/0.94
sum product2010
keep city p2010 product2010
sort city
save corr2010, replace

**********************************
* CITY LIVING STANDARDS PRE-1910 *
**********************************

**** WELFARE RATIOS ****

* If we restrict the sample to the cities > 300,000 inhabitants.

clear
import excel "welfare_ratios_pre_1910.xls", sheet("raw") firstrow
keep if city_size_000s >= 300
drop if city_size == . |  welfare == .
count
* 61
gsort- welfare
gen rank_product = _n
gsort- city_size_000s
gen rank_pop = _n
keep city rank* city_size_000s
save wr_300, replace 

* If we restrict the sample to the cities > 100,000 inhabitants.

clear
import excel "welfare_ratios_pre_1910.xls", sheet("raw") firstrow
keep if city_size_000s >= 100
drop if city_size == . |  welfare == .
count
* 111
gsort- welfare
gen rank_product = _n
gsort- city_size_000s
gen rank_pop = _n
keep city rank* city_size_000s
save wr_100, replace 

************
* ANALYSIS *
************

use corr2010, clear
merge city using corr2000
tab _m
drop _m
drop if p2010 == .
* We use Stockholm as a benchmkark to merge the two data sets.
* Product in 1998 = .9619341
* Product2 in 2012 = .9531915
replace product2000 = product2000/.9619341
replace product2010 = product2010/.9531915
replace product2010 = product2000 if product2010 == . & product2000 != .
keep if product2010 != .
count
* 157 instead of 115 before
ren product2010 product_all
drop if product_all == . | p2010 == .
gsort- p2010
gen rank_pop = _n
*keep if rank_pop <= 61
keep if rank_pop <= 111
gsort- product_all
gen rank_product = _n
gen sample = "new" 
*append using wr_300
append using wr_100
* We use the cities above 100,000 inh. pre-1910.
* Since we have 111 such cities then, we use the top 111 cities today.
replace sample = "old" if sample == ""
replace rank_product = -rank_product 
replace rank_pop = -rank_pop
gen pop = p2010
replace pop = city_size_000s if pop == . & city_size_000s != .
label var rank_product "Rank in terms of city product"
label var rank_pop "Rank in terms of city population"
label var sample "Sample: old/new"
label var city_size_000s "City size"
label var pop "Population in 2010"

*** Figure 8 ***

twoway (scatter rank_product rank_pop if sample == "new", mcolor(gs8) msize(medsmall) msymbol(square)) (lfit rank_product rank_pop [pw=pop] if sample == "new", lcolor(black) lwidth(medthick) lpattern(solid))(scatter rank_product rank_pop if sample == "old", mcolor(black) msize(medium) msymbol(circle)) (lfit rank_product rank_pop [pw=pop] if sample == "old", lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Rank Wealth) ytitle(, size(medium) color(black) margin(zero)) xtitle(Rank Population) xtitle(, size(medium) color(black) margin(zero)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) legend(order(1 "New" 2 "New" 3 "Old" 4 "Old") rows(1))
* We use graph editor to manually edit the figure, before we export it.
graph export figure_8.png, replace width(2620) height(1908)
reg rank_product rank_pop [pw=pop] if sample == "new", robust
reg rank_product rank_pop [pw=pop] if sample == "old", robust
* We manually add these regression results to the figure.

*** Figure A.22 ***

* To obtain Figure A.22, we only use the 61 cities above 300,000 inhabitants pre-1910.
use corr2010, clear
merge city using corr2000
tab _m
drop _m
drop if p2010 == .
* We use Stockholm as a benchmkark to merge the two data sets.
* Product in 1998 = .9619341
* Product2 in 2012 = .9531915
replace product2000 = product2000/.9619341
replace product2010 = product2010/.9531915
replace product2010 = product2000 if product2010 == . & product2000 != .
keep if product2010 != .
count
* 157 instead of 115 before
ren product2010 product_all
drop if product_all == . | p2010 == .
gsort- p2010
gen rank_pop = _n
keep if rank_pop <= 61
*keep if rank_pop <= 111
gsort- product_all
gen rank_product = _n
gen sample = "new" 
append using wr_300
*append using wr_100
* We use the cities above 100,000 inh. pre-1910.
* Since we have 111 such cities then, we use the top 111 cities today.
replace sample = "old" if sample == ""
replace rank_product = -rank_product 
replace rank_pop = -rank_pop
gen pop = p2010
replace pop = city_size_000s if pop == . & city_size_000s != .

twoway (scatter rank_product rank_pop if sample == "new", mcolor(gs8) msize(medsmall) msymbol(square)) (lfit rank_product rank_pop [pw=pop] if sample == "new", lcolor(black) lwidth(medthick) lpattern(solid))(scatter rank_product rank_pop if sample == "old", mcolor(black) msize(medium) msymbol(circle)) (lfit rank_product rank_pop [pw=pop] if sample == "old", lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Rank Wealth) ytitle(, size(medium) color(black) margin(zero)) xtitle(Rank Population) xtitle(, size(medium) color(black) margin(zero)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) legend(order(1 "New" 2 "New" 3 "Old" 4 "Old") rows(1))
* We use graph editor to manually edit the figure, before we export it.
graph export figure_A22.png, replace width(2620) height(1908)
reg rank_product rank_pop [pw=pop] if sample == "new", robust
reg rank_product rank_pop [pw=pop] if sample == "old", robust
* We manually add these regression results to the figure.

